Orange Network Add-on Documentation
===================================

Orange Network is an add-on for `Orange`_ data mining software package. It
provides modules and widgets for network visualization and analysis.

.. _Orange: http://orange.biolab.si/addons


Scripting Reference
-------------------

.. toctree::
   :maxdepth: 1

   Orange.network

Installation
------------

`Install Orange`_ data mining suite from the Orange website. Start Orange Canvas,
navigate to Options / Add-ons, and check the Network add-on.

To install from PyPi_ run::

    pip install orange-network

To install from source code run::

    python setup.py install

To build Python egg run::

    python setup.py bdist_egg

To install add-on in `development mode`_ run::

    python setup.py develop

.. _development mode: http://packages.python.org/distribute/setuptools.html#development-mode
.. _PyPi: http://pypi.python.org/pypi
.. _Install Orange: http://orange.biolab.si/download

Source Code and Issue Tracker
-----------------------------

Source code is available on Bitbucket_. For issues and wiki we use Trac_.

.. _Bitbucket: https://bitbucket.org/mstajdohar/orange-network
.. _Trac: http://orange.biolab.si/trac/

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
